/**
 *  Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 *  Licensed under the Apache License, Version 2.0 (the "License"). You may not use this file except in compliance
 *  with the License. A copy of the License is located at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  or in the 'license' file accompanying this file. This file is distributed on an 'AS IS' BASIS, WITHOUT WARRANTIES
 *  OR CONDITIONS OF ANY KIND, express or implied. See the License for the specific language governing permissions
 *  and limitations under the License.
 */
import * as cloudfront from 'aws-cdk-lib/aws-cloudfront';
import * as s3 from 'aws-cdk-lib/aws-s3';
import { Construct } from 'constructs';
/**
 * Properties to use to customize an S3 Origin.
 */
export interface S3OacOriginProps extends cloudfront.OriginProps {
    /**
     * The origin access control that will be used when calling your S3 bucket.
     */
    readonly originAccessControl?: cloudfront.CfnOriginAccessControl;
}
/**
 * A custom implementation of S3Origin that allows an origin access control (OAC) to be used instead of
 * an origin access identity (OAI), which is currently the only option supported by default CDK.
 */
export declare class S3OacOrigin implements cloudfront.IOrigin {
    private readonly origin;
    constructor(bucket: s3.IBucket, props: S3OacOriginProps);
    bind(scope: Construct, options: cloudfront.OriginBindOptions): cloudfront.OriginBindConfig;
}
